@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.8.1";
+        "23.0.2";
 
     private static final String java_version_date =
-        "2023-08-24";
+        "2025-01-21";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.8.1+1";
+        "23.0.2+7";
 
     private static final String VERSION_NUMBER =
-        "17.0.8.1";
+        "23.0.2";
 
     private static final String VERSION_SPECIFICATION =
-        "17";
+        "23";
 
     private static final String VERSION_BUILD =
-        "1";
+        "7";
 
     private static final String VERSION_PRE =
         "";
@@ -70,7 +70,7 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "61.0";
+        "67.0";
 
     private static final String VENDOR =
         "Eclipse Adoptium";
@@ -83,7 +83,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "Temurin-17.0.8.1+1";
+        "Temurin-23.0.2+7";
 
     private static String VENDOR_URL_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
@@ -109,6 +109,10 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
+
+        // Uncomment next props.put call after the first maintenance release for a
+        // platform specification is done and set the MR number, starting at "1".
+        // props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
@@ -182,25 +186,13 @@ class VersionProps {
         }
     }
 
-    /**
-     * In case you were wondering this method is called by java -version.
-     */
-    public static void print(boolean err) {
-        print(err, false);
-    }
 
-    /**
-     * This is the same as print except that it adds an extra line-feed
-     * at the end, typically used by the -showversion in the launcher
-     */
-    public static void println(boolean err) {
-        print(err, true);
-    }
 
     /**
      * Print version info.
+     * In case you were wondering this method is called by java -version.
      */
-    private static void print(boolean err, boolean newln) {
+    private static void print(boolean err) {
         PrintStream ps = err ? System.err : System.out;
 
         /* First line: platform version. */
